# AUTOGENERATED! DO NOT EDIT! File to edit: 99_test.ipynb (unless otherwise specified).

__all__ = ['test_grid_search_first_entries', 'test_grid_search_default_n', 'test_grid_search_default_load_test']

# Comes from 00_core.ipynb, cell
def test_grid_search_first_entries():
    from .core import grid_search
    generator = grid_search(x_range=[0, 1], y_range=[0, 1])
    assert list(next(generator)) == [0.0, 1.0]
    assert list(next(generator)) == [1.0, 1.0]
    assert list(next(generator)) == [0.0, 0.0]
    assert list(next(generator)) == [1.0, 0.0]
    assert list(next(generator)) == [0.5, 1.0]


def test_grid_search_default_n():
    from .core import grid_search
    assert list(grid_search(x_range=[0, 1], y_range=[0, 1]))


def test_grid_search_default_load_test():
    from .core import grid_search
    from collections import deque

    deque(grid_search(x_range=[0, 1], y_range=[0, 1], n=100_000), maxlen=0)
    assert True